@@ -160,16 +160,17 @@ sub Delete () {
 
 sub _gc_expired () { 
   my ($this) = @_; 
-  
+ 
+  my $time = time(); 
   foreach my $cache_key (keys %{$this->_KeyCache}) {
     my $cache_time = $this->_RecordCache->{$cache_key}{'time'} || 0;  
     $this->_expire($cache_key) 
-      if ((time() - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
+      if (($time - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
   }
   foreach my $cache_key (keys %{$this->_RecordCache}) {
     my $cache_time = $this->_RecordCache->{$cache_key}{'time'} || 0 ;  
     $this->_expire($cache_key) 
-      if ((time() - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
+      if (($time - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
   }
 }
 
